# ifndef yyMakeReductions
# define yyMakeReductions

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeReductions_Exit) ARGS ((void));

extern void MakeReductions ARGS ((tTree t));

extern void BeginMakeReductions ARGS ((void));
extern void CloseMakeReductions ARGS ((void));

# endif
